@@ -4,6 +4,7 @@ Module that provide non-asynchronous functions for using the somtoday API
 '''
 import base64
 import re
+import pytz
 from typing import Any, Union, Generator
 from pathlib import Path
 from datetime import datetime
@@ -14,6 +15,7 @@ from string import ascii_lowercase, digits
 from urllib.parse import urlparse, parse_qs
 import httpx
 
+CET = pytz.timezone("Europe/Amsterdam")
 
 class PasFoto:
     def __init__(self, b64url: str):
@@ -93,6 +95,9 @@ class Subject:
         self.end_hour: int = kwargs.get("endhour")
         self.location: str = kwargs.get("location")
         self.teacher_short: str = kwargs.get("teacher_shortcut")
+    
+    def __hash__(self) -> int:
+        return hash(self.subject_name) + hash(self.begin_time) + hash(self.end_time) + hash(self.subject_short) + hash(self.begin_hour) + hash(self.end_hour) + hash(self.location) + hash(self.teacher_short)
 
 
 class Student:
@@ -175,7 +180,7 @@ class Student:
             items: list[dict] = to_dict["items"]
             self.cijfers = []
             for item in items:
-                tijd_nagekeken = datetime.fromisoformat(item["datumInvoer"])
+                tijd_nagekeken = datetime.fromisoformat(item["datumInvoer"]).replace(tzinfo=CET)
                 resultaat = item.get("resultaat", "0")
                 leerjaar = item['leerjaar']
                 vak = item["vak"]["naam"]
@@ -244,9 +249,9 @@ class Student:
             docent_afkorting: str = item.get(
                 "additionalObjects").get("docentAfkortingen")
             begin_time: datetime = datetime.fromisoformat(
-                item.get("beginDatumTijd"))
+                item.get("beginDatumTijd")).replace(tzinfo=CET)
             end_time: datetime = datetime.fromisoformat(
-                item.get("eindDatumTijd"))
+                item.get("eindDatumTijd")).replace(tzinfo=CET)
             target_object = Subject(subject=subject_name,
                                     begindt=begin_time,
                                     enddt=end_time,
@@ -303,7 +308,7 @@ class Student:
             self.gender = "Male" if to_dict.get(
                 "geslacht") == "Man" else "Female"
             year, month, day = to_dict.get("geboortedatum").split("-")
-            self.birth_datetime = datetime(int(year), int(month), int(day))
+            self.birth_datetime = datetime(int(year), int(month), int(day), tzinfo=CET)
         return True
 
     @property
@@ -316,6 +321,7 @@ class Student:
         return School(self.school_name, self.school_uuid)
 
 
+
 class School:
     '''
     Model that represents a school.
